# Oneurai SDK 🚀

**A powerful AI client library for Oneurai MLOps platform.**

`oneurai` is a Python library designed to simplify the interaction with the Oneurai platform. It allows developers and data scientists to easily manage **AI Models**, **Datasets**, and **Source Code Repositories** directly from their Python scripts.

---

## 📦 Installation

You can install the library directly using pip:

```bash
pip install oneurai